@@ -1,10 +1,8 @@
 # (C) Copyright 2015-2016 Hewlett Packard Enterprise Development LP
 # Copyright 2017 SUSE Linux GmbH
-# Copyright 2017 OP5 AB
 
 """ Util functions to assist in detection.
 """
-import argparse
 import logging
 import os
 import pwd
@@ -135,6 +133,7 @@ def get_agent_username():
     return _DETECTED_AGENT_USER
 
 
+# NOTE(trebskit) a little poetry never hurt anyone before...right ?
 def load_oslo_configuration(from_cmd, in_project,
                             for_opts, of_prog=None):
     """Loads configuration of an OpenStack project.
@@ -184,19 +183,7 @@ def load_oslo_configuration(from_cmd, in_project,
     # /usr/bin/python, /usr/bin/python3
     # and next actual binary of the program
     # /usr/local/bin/nova-compute
-    # NOTE(tobiajo) Just keep built-in options for oslo.config
-    args = []
-    parser = argparse.ArgumentParser()
-    parser.add_argument('--config-file')
-    parser.add_argument('--config-dir')
-    namespace, _ = parser.parse_known_args(from_cmd[2:])
-    if namespace.config_file:
-        args.append('--config-file')
-        args.append(namespace.config_file)
-    if namespace.config_dir:
-        args.append('--config-dir')
-        args.append(namespace.config_dir)
-
+    args = from_cmd[2:]
     conf_holder(
         args=args,
         project=in_project,
