@@ -1,16 +1,18 @@
-# (C) Copyright 2015-2016 Hewlett Packard Enterprise Development Company LP
+# (C) Copyright 2015-2017 Hewlett Packard Enterprise Development Company LP
 import unittest
 
 import monasca_agent.common.aggregator as aggregator
 import monasca_agent.common.metrics as metrics_pkg
 
+import monasca_common.validation.metrics as metric_validator
+
 # a few valid characters to test
 valid_name_chars = ".'_-"
-invalid_name_chars = " <>={}(),\"\\\\;&"
+invalid_name_chars = metric_validator.INVALID_CHARS
 
 # a few valid characters to test
 valid_dimension_chars = " .'_-"
-invalid_dimension_chars = "<>={}(),\"\\\\;&"
+invalid_dimension_chars = metric_validator.INVALID_CHARS
 
 
 class TestMetricsAggregator(unittest.TestCase):
@@ -80,7 +82,7 @@ class TestMetricsAggregator(unittest.TestCase):
                            5,
                            dimensions=dimensions,
                            value_meta=value_meta,
-                           exception=aggregator.InvalidMetricName)
+                           exception=metric_validator.InvalidMetricName)
 
     def testInvalidMetricNameEmpty(self):
         dimensions = {'A': 'B', 'B': 'C', 'D': 'E'}
@@ -89,7 +91,7 @@ class TestMetricsAggregator(unittest.TestCase):
                            5,
                            dimensions=dimensions,
                            value_meta=value_meta,
-                           exception=aggregator.InvalidMetricName)
+                           exception=metric_validator.InvalidMetricName)
 
     def testInvalidMetricNameNonStr(self):
         dimensions = {'A': 'B', 'B': 'C', 'D': 'E'}
@@ -98,7 +100,7 @@ class TestMetricsAggregator(unittest.TestCase):
                            5,
                            dimensions=dimensions,
                            value_meta=value_meta,
-                           exception=aggregator.InvalidMetricName)
+                           exception=metric_validator.InvalidMetricName)
 
     def testInvalidMetricRestrictedCharacters(self):
         dimensions = {'A': 'B', 'B': 'C', 'D': 'E'}
@@ -107,7 +109,7 @@ class TestMetricsAggregator(unittest.TestCase):
                            5,
                            dimensions=dimensions,
                            value_meta=value_meta,
-                           exception=aggregator.InvalidMetricName)
+                           exception=metric_validator.InvalidMetricName)
 
     def testInvalidDimensionEmptyKey(self):
         dimensions = {'A': 'B', '': 'C', 'D': 'E'}
@@ -116,7 +118,7 @@ class TestMetricsAggregator(unittest.TestCase):
                            5,
                            dimensions=dimensions,
                            value_meta=value_meta,
-                           exception=aggregator.InvalidDimensionKey)
+                           exception=metric_validator.InvalidDimensionKey)
 
     def testInvalidDimensionEmptyValue(self):
         dimensions = {'A': 'B', 'B': 'C', 'D': ''}
@@ -125,7 +127,7 @@ class TestMetricsAggregator(unittest.TestCase):
                            5,
                            dimensions=dimensions,
                            value_meta=value_meta,
-                           exception=aggregator.InvalidDimensionValue)
+                           exception=metric_validator.InvalidDimensionValue)
 
     def testInvalidDimensionNonStrKey(self):
         dimensions = {'A': 'B', 4: 'C', 'D': 'E'}
@@ -134,7 +136,7 @@ class TestMetricsAggregator(unittest.TestCase):
                            5,
                            dimensions=dimensions,
                            value_meta=value_meta,
-                           exception=aggregator.InvalidDimensionKey)
+                           exception=metric_validator.InvalidDimensionKey)
 
     def testInvalidDimensionNonStrValue(self):
         dimensions = {'A': 13.3, 'B': 'C', 'D': 'E'}
@@ -143,7 +145,7 @@ class TestMetricsAggregator(unittest.TestCase):
                            5,
                            dimensions=dimensions,
                            value_meta=value_meta,
-                           exception=aggregator.InvalidDimensionValue)
+                           exception=metric_validator.InvalidDimensionValue)
 
     def testInvalidDimensionKeyLength(self):
         dimensions = {'A'*256: 'B', 'B': 'C', 'D': 'E'}
@@ -153,7 +155,7 @@ class TestMetricsAggregator(unittest.TestCase):
                            5,
                            dimensions=dimensions,
                            value_meta=value_meta,
-                           exception=aggregator.InvalidDimensionKey)
+                           exception=metric_validator.InvalidDimensionKey)
 
     def testInvalidDimensionValueLength(self):
         dimensions = {'A': 'B', 'B': 'C'*256, 'D': 'E'}
@@ -162,7 +164,7 @@ class TestMetricsAggregator(unittest.TestCase):
                            5,
                            dimensions=dimensions,
                            value_meta=value_meta,
-                           exception=aggregator.InvalidDimensionValue)
+                           exception=metric_validator.InvalidDimensionValue)
 
     def testInvalidDimensionKeyRestrictedCharacters(self):
         dimensions = {'A': 'B', 'B': 'C', '(D)': 'E'}
@@ -171,7 +173,7 @@ class TestMetricsAggregator(unittest.TestCase):
                            5,
                            dimensions=dimensions,
                            value_meta=value_meta,
-                           exception=aggregator.InvalidDimensionKey)
+                           exception=metric_validator.InvalidDimensionKey)
 
     def testInvalidDimensionValueRestrictedCharacters(self):
         dimensions = {'A': 'B;', 'B': 'C', 'D': 'E'}
@@ -180,7 +182,7 @@ class TestMetricsAggregator(unittest.TestCase):
                            5,
                            dimensions=dimensions,
                            value_meta=value_meta,
-                           exception=aggregator.InvalidDimensionValue)
+                           exception=metric_validator.InvalidDimensionValue)
 
     def testInvalidDimensionKeyLeadingUnderscore(self):
         dimensions = {'_A': 'B', 'B': 'C', 'D': 'E'}
@@ -189,7 +191,7 @@ class TestMetricsAggregator(unittest.TestCase):
                            5,
                            dimensions=dimensions,
                            value_meta=value_meta,
-                           exception=aggregator.InvalidDimensionKey)
+                           exception=metric_validator.InvalidDimensionKey)
 
     def testInvalidValue(self):
         dimensions = {'A': 'B', 'B': 'C', 'D': 'E'}
@@ -198,7 +200,7 @@ class TestMetricsAggregator(unittest.TestCase):
                            "value",
                            dimensions=dimensions,
                            value_meta=value_meta,
-                           exception=aggregator.InvalidValue)
+                           exception=metric_validator.InvalidValue)
 
     def testValidNameChars(self):
         for c in valid_name_chars:
@@ -209,7 +211,7 @@ class TestMetricsAggregator(unittest.TestCase):
         for c in invalid_name_chars:
             self.submit_metric('test{}counter'.format(c), 2,
                                dimensions={"test-key": "test-value"},
-                               exception=aggregator.InvalidMetricName)
+                               exception=metric_validator.InvalidMetricName)
 
     def testValidDimensionChars(self):
         for c in valid_dimension_chars:
@@ -220,10 +222,10 @@ class TestMetricsAggregator(unittest.TestCase):
         for c in invalid_dimension_chars:
             self.submit_metric('test-counter', 2,
                                dimensions={'test{}key'.format(c): 'test-value'},
-                               exception=aggregator.InvalidDimensionKey)
+                               exception=metric_validator.InvalidDimensionKey)
             self.submit_metric('test-counter', 2,
                                dimensions={'test-key': 'test{}value'.format(c)},
-                               exception=aggregator.InvalidDimensionValue)
+                               exception=metric_validator.InvalidDimensionValue)
 
     def testTooManyValueMeta(self):
         dimensions = {'A': 'B', 'B': 'C', 'D': 'E'}
@@ -234,7 +236,7 @@ class TestMetricsAggregator(unittest.TestCase):
                            2,
                            dimensions=dimensions,
                            value_meta=value_meta,
-                           exception=aggregator.InvalidValueMeta)
+                           exception=metric_validator.InvalidValueMeta)
 
     def testEmptyValueMetaKey(self):
         dimensions = {'A': 'B', 'B': 'C', 'D': 'E'}
@@ -243,21 +245,12 @@ class TestMetricsAggregator(unittest.TestCase):
                            2,
                            dimensions=dimensions,
                            value_meta=value_meta,
-                           exception=aggregator.InvalidValueMeta)
-
-    def testEmptyValueMetaKey(self):
-        dimensions = {'A': 'B', 'B': 'C', 'D': 'E'}
-        value_meta = {'': 'BBB'}
-        self.submit_metric("Foo",
-                           2,
-                           dimensions=dimensions,
-                           value_meta=value_meta,
-                           exception=aggregator.InvalidValueMeta)
+                           exception=metric_validator.InvalidValueMeta)
 
     def testTooLongValueMetaKey(self):
         dimensions = {'A': 'B', 'B': 'C', 'D': 'E'}
         key = "K"
-        for i in range(0, aggregator.VALUE_META_NAME_MAX_LENGTH):
+        for i in range(0, metric_validator.VALUE_META_NAME_MAX_LENGTH):
             key = "{}{}".format(key, "1")
         value_meta = {key: 'BBB'}
         print(key)
@@ -265,22 +258,13 @@ class TestMetricsAggregator(unittest.TestCase):
                            2,
                            dimensions=dimensions,
                            value_meta=value_meta,
-                           exception=aggregator.InvalidValueMeta)
-
-    def testEmptyValueMetaKey(self):
-        dimensions = {'A': 'B', 'B': 'C', 'D': 'E'}
-        value_meta = {'': 'BBB'}
-        self.submit_metric("Foo",
-                           2,
-                           dimensions=dimensions,
-                           value_meta=value_meta,
-                           exception=aggregator.InvalidValueMeta)
+                           exception=metric_validator.InvalidValueMeta)
 
     def testTooLargeValueMeta(self):
         dimensions = {'A': 'B', 'B': 'C', 'D': 'E'}
         value_meta_value = ""
         num_value_meta = 10
-        for i in range(0, aggregator.VALUE_META_VALUE_MAX_LENGTH/num_value_meta):
+        for i in range(0, metric_validator.VALUE_META_VALUE_MAX_LENGTH/num_value_meta):
             value_meta_value = '{}{}'.format(value_meta_value, '1')
 
         value_meta = {}
@@ -290,4 +274,4 @@ class TestMetricsAggregator(unittest.TestCase):
                            2,
                            dimensions=dimensions,
                            value_meta=value_meta,
-                           exception=aggregator.InvalidValueMeta)
+                           exception=metric_validator.InvalidValueMeta)
